pub struct Sum4 {
pub sum: u64,
/* private fields */
}Fields
sum: u64Trait Implementations
Sourceimpl From<Sum4> for GlobalProcess
impl From<Sum4> for GlobalProcess
Sourceimpl Process<SessionB, ()> for Sum4
impl Process<SessionB, ()> for Sum4
fn new(inner: Inner<SessionB>) -> Self
fn extract_result( session_results: &mut VecMap<GlobalPresult>, ) -> Result<(), String>
fn inner_ref(&self) -> &Inner<SessionB>
fn inner_mut(&mut self) -> &mut Inner<SessionB>
fn result_ref(&self) -> &()
fn result_mut(&mut self) -> &mut ()
fn global_result(&mut self) -> GlobalPresult
fn handle_message(&mut self, message: GlobalMessage) -> ControlFlow
fn update(&mut self) -> ControlFlow
Sourcefn initialize(&mut self)
fn initialize(&mut self)
Does nothing by default, may be overridden.
fn id(&self) -> &CTX::PIDwhere
CTX: 'static,
fn kind(&self) -> &Kindwhere
CTX: 'static,
fn state_id(&self) -> StateId
fn def(&self) -> &Def<CTX>
fn sourcepoints(&self) -> &VecMap<Box<dyn Sourcepoint<CTX>>>
fn sourcepoints_mut(&mut self) -> &mut VecMap<Box<dyn Sourcepoint<CTX>>>
Sourcefn endpoints(&self) -> Ref<'_, Option<VecMap<Box<dyn Endpoint<CTX>>>>>
fn endpoints(&self) -> Ref<'_, Option<VecMap<Box<dyn Endpoint<CTX>>>>>
This method returns a
Ref <Option <...>> because during the run loop
the endpoints will be unavailable as they are being iterated over.
Endpoints are automatically waited on or polled in the appropriate
run_* function. Endpoints will be present for the calls to terminate
or initialize, either before or after the run loop, respectively.Sourcefn endpoints_mut(
&mut self,
) -> RefMut<'_, Option<VecMap<Box<dyn Endpoint<CTX>>>>>
fn endpoints_mut( &mut self, ) -> RefMut<'_, Option<VecMap<Box<dyn Endpoint<CTX>>>>>
This method returns a
Ref <Option <...>> because during the run loop
the endpoints will be unavailable as they are being iterated over.
Endpoints are automatically waited on or polled in the appropriate
run_* function. Endpoints will be present for the calls to terminate
or initialize, either before or after the run loop, respectively.Sourcefn take_endpoints(&self) -> VecMap<Box<dyn Endpoint<CTX>>>
fn take_endpoints(&self) -> VecMap<Box<dyn Endpoint<CTX>>>
This method is used within the process
run_* methods to get the
endpoints without borrowing the process. Endpoints will then be replaced
with None and unavailable within the run loop. Read morefn send<M: Message<CTX>>(
&self,
channel_id: CTX::CID,
message: M,
) -> Result<(), SendError<CTX::GMSG>>where
CTX: 'static,
fn send_to<M: Message<CTX>>(
&self,
channel_id: CTX::CID,
recipient: CTX::PID,
message: M,
) -> Result<(), SendError<CTX::GMSG>>where
CTX: 'static,
Sourcefn run(&mut self)where
Self: Sized + 'static,
CTX: 'static,
fn run(&mut self)where
Self: Sized + 'static,
CTX: 'static,
Run a process to completion and send the result on the result channel.
Sourcefn run_continue(self) -> Option<()>where
Self: Sized + 'static,
CTX: 'static,
fn run_continue(self) -> Option<()>where
Self: Sized + 'static,
CTX: 'static,
Run a process to completion, send the result to the session, and proceed
with the continuation received from the session.
Sourcefn run_asynchronous(&mut self)where
Self: Sized,
CTX: 'static,
fn run_asynchronous(&mut self)where
Self: Sized,
CTX: 'static,
Asynchronous run loop waits for messages on the single endpoint held by
this process and calls the process update method for every $n >= 1$
messages as specified by the process kind.
Sourcefn run_isochronous(&mut self)where
Self: Sized,
CTX: 'static,
fn run_isochronous(&mut self)where
Self: Sized,
CTX: 'static,
This function implements a fixed-timestep update loop. Read more
Sourcefn run_mesochronous(&mut self)where
Self: Sized,
CTX: 'static,
fn run_mesochronous(&mut self)where
Self: Sized,
CTX: 'static,
This function implements a rate-limited update loop. Read more
Sourcefn run_anisochronous(&mut self)where
Self: Sized,
CTX: 'static,
fn run_anisochronous(&mut self)where
Self: Sized,
CTX: 'static,
An un-timed run loop that polls for messages.
Sourceimpl TryFrom<GlobalProcess> for Sum4
impl TryFrom<GlobalProcess> for Sum4
impl Presult<SessionB, Sum4> for ()